package bzh.billos.games.omgb.game.engine;

import java.util.ArrayList;
import java.util.Random;

import org.newdawn.slick.Color;
import org.newdawn.slick.Graphics;

import bzh.billos.games.omgb.game.engine.actions.MyDrawable;
import bzh.billos.games.omgb.game.engine.characters.Character;
import bzh.billos.games.omgb.game.states.InGameState;

public class Case implements MyDrawable{
	
	private Character character;
	private CaseType type;
	
	private int x;
	private int y;
	private int width;
	private int height;
	
	public static Color skyColor = new Color(211,211,211);
	public static Color seaColor = new Color(57,190,240);
	
	
	
	
	public Case(CaseType ct, int x, int y, int width, int height){
		this.type 	= ct;
		this.x 		= x;
		this.y 		= y;
		this.width 	= width;
		this.height = height;
	}
	
	public void setCharacter(Character c){
		this.character = c;
		this.character.setCase(this);
	}
	
	public void removeCharacter(){
		if(this.character != null){
			this.character.setCase(null);
		}
		this.character = null;
	}
	
	public Character getCharacter(){
		return this.character;
	}
	
	public boolean containsSomething(){
		return this.character != null;
	}
	
	public CaseType getType(){
		return this.type;
	}
	
	public int getX() {
		return x;
	}

	public int getY() {
		return y;
	}

	public int getWidth() {
		return width;
	}

	public int getHeight() {
		return height;
	}
	
	
	
	
	

	@Override
	public void draw(Graphics g, Case c) {}
	@Override
	public void draw(Graphics g){
		// draw bg
		Color color = (this.type == CaseType.SKY) ? skyColor : seaColor;
		g.setColor(color);
		g.fillRect(x, y, width, height);
		g.setColor(Color.black);
		g.drawRect(x, y, width, height);
		// draw contained character
		
		if(containsSomething()){
			this.character.draw(g, this);
		}
		
	}
	
	
	
	
	
	
	
	
	
	
	
	/*
	 * STATIC
	 */ 
	
	public static Case getRandomCase(Case[][] map, CaseType ct, boolean containsSomething){
		
		ArrayList<Case> list = new ArrayList<Case>();
		for(Case[] arr : map){
			for (Case c : arr) {
				if(c.getType() == ct && c.containsSomething() == containsSomething){
					list.add(c);
				}
			}
		}
		int index = (new Random()).nextInt(list.size());
		return list.get(index);
	}
	
	public static Case getNeighborCase(Case[][] map, int currentX, int currentY, int x, int y){
		Case ret = null;
		
		int newX = currentX/InGameState.X_SIZE+x;
		int newY = currentY/InGameState.Y_SIZE+y;
		
		if(newX >= 0 && newX < map.length 		&& 		newY >= 0 && newY < map[0].length){
			ret = map[newX][newY];
		}
		
		return ret;
	}


	
}
