package bzh.billos.games.omgb.game.engine.characters;

import org.newdawn.slick.Color;
import org.newdawn.slick.Graphics;
import org.newdawn.slick.Image;

import bzh.billos.games.omgb.game.engine.Case;
import bzh.billos.games.omgb.game.engine.CaseType;
import bzh.billos.games.omgb.game.engine.actions.Attacking;
import bzh.billos.games.omgb.game.states.InGameState;
import bzh.billos.games.omgb.util.ImageCache;


public class Bird extends Character implements Attacking {

	private boolean isAttacking;
	private Fish target;
	private Case targetPosition;
	
	public Bird(Case[][] map, Fish target) {
		super(map);
		this.target = target;
	}

	@Override
	public void attack() {
		this.isAttacking = true;
		
	}

	@Override
	public void draw(Graphics g) {
	}

	@Override
	public void draw(Graphics g, Case c) {
		
		int x = c.getX() + c.getWidth()/4;
		int y = c.getY() + c.getHeight()/4;
		int width = c.getWidth()/2;
		int height = c.getWidth()/2;
		
		Image img = ImageCache.imgBird;
		Color color = (c.getType() == CaseType.SEA) ? Case.seaColor : Case.skyColor;
		g.drawImage(img, x, y, x+width,y+height, 0, 0, img.getWidth(), img.getHeight(), color);

	}

	public void auto() {
		if(hasPosition()){
			// Bird is attacking (descending)
			if(isAttacking){
				int currentX = this.position.getX()/InGameState.X_SIZE;
				int currentY = this.position.getY()/InGameState.Y_SIZE;
				int targetX = targetPosition.getX()/InGameState.X_SIZE;
				int targetY = targetPosition.getY()/InGameState.Y_SIZE;
				
				int x = 0;
				int y = 0;
				
				if(currentX < targetX){
					x++;
				} else if(currentX > targetX){
					x--;
				}
				
				if(currentY < targetY){
					y++;
				} else if(currentY > targetY){
					y--;
				}
				this.move(x, y);
				if(currentX == targetX && currentY == targetY){
					isAttacking = false;
				}
				
			// Bird is not attacking
			} else {
				// Bird can attack
				if(this.position.getY()/InGameState.Y_SIZE < 1) {
					isAttacking = true;
					targetPosition = target.position;
					
				// Bird has to go up 
				} else {
					this.move(0, -1);
				}
			}
		}
	}
	
	private boolean hasPosition() {
		return this.position != null;
	}

	@Override
	public void move(int x, int y) {
		if(x >= -1 && x <= +1 && y >= -1 && y <= +1){
			Case newCase = Case.getNeighborCase(map, position.getX(), position.getY(), x, y);
			if(newCase != null){
				
				if(!newCase.containsSomething()){
					position.removeCharacter();
					newCase.setCharacter(this);
					position = newCase;
				} else if(newCase.containsSomething()){
					Character c = newCase.getCharacter();
					if(c==target){
						targetPosition.removeCharacter();
						position.removeCharacter();
						targetPosition.setCharacter(this);
						position = newCase;
						target.kill(this);
					} else {
						isAttacking = false;
					}
				}
				
			}

		}
	}

	
}
