package bzh.billos.games.omgb.game.states;

import java.util.ArrayList;

import org.newdawn.slick.Color;
import org.newdawn.slick.GameContainer;
import org.newdawn.slick.Graphics;
import org.newdawn.slick.SlickException;
import org.newdawn.slick.state.BasicGameState;
import org.newdawn.slick.state.StateBasedGame;

import bzh.billos.games.omgb.Launcher;
import bzh.billos.games.omgb.game.engine.Case;
import bzh.billos.games.omgb.game.engine.CaseType;
import bzh.billos.games.omgb.game.engine.characters.Bird;
import bzh.billos.games.omgb.game.engine.characters.Fish;
import bzh.billos.games.omgb.util.GameDictionnary;
import bzh.billos.games.omgb.util.ImageCache;


public class InGameState extends BasicGameState {

	private static final int id = 1;
	public static final int X_SIZE = 100;
	public static final int Y_SIZE = 100;
	public static final int BIRDS_AMOUNT = 1;
	private Case[][] map;
	private Fish fish;
	private ArrayList<Bird> birds;
	private boolean over;
	private boolean pause;
	private long timestamp;
	private long score;
	
	@Override
	public void init(GameContainer container, StateBasedGame state) throws SlickException {
		ImageCache.getCache();
		this.over = false;
		this.pause = true;
		int xAmount = Launcher.X_SIZE/X_SIZE;
		int yAmount = Launcher.Y_SIZE/Y_SIZE;
		this.map = new Case[xAmount][yAmount];
		birds = new ArrayList<Bird>();
		
		for (int i = 0; i < xAmount; i++) {
			for (int j = 0; j < yAmount; j++) {
				CaseType ct = (j < yAmount/4) ? CaseType.SKY : CaseType.SEA;
				map[i][j] = new Case(ct, i*X_SIZE, j*Y_SIZE, X_SIZE, Y_SIZE);
			}
		}
		
		// spawn
		fish = new Fish(map, this);
		Case spawn = Case.getRandomCase(map, CaseType.SEA, false);
		spawn.setCharacter(fish);
		
		for (int i = 0; i < BIRDS_AMOUNT; i++) {
			spawnBird();
		}
		this.timestamp = System.currentTimeMillis();
		
		
	}

	private void spawnBird() {
		Bird b = new Bird(map, fish);
		Case c = Case.getRandomCase(map, CaseType.SKY, false);
		birds.add(b);
		c.setCharacter(b);
	}

	@Override
	public void render(GameContainer container, StateBasedGame state, Graphics graphics) throws SlickException {
		if(this.pause){
			graphics.setColor(Color.red);
			graphics.drawString(GameDictionnary.getInstance().get("rulesPause"), 500, 500);
			graphics.drawString(GameDictionnary.getInstance().get("rulesMove"), 500, 550);
			graphics.drawString(GameDictionnary.getInstance().get("rulesPlus"), 500, 600);
			graphics.drawString(GameDictionnary.getInstance().get("rulesGoal"), 500, 650);
		} else {
			// draw cases
			for(Case[] arr : map){
				for(Case c : arr){
					c.draw(graphics);
				}
			}
			// draw LOST
			if(this.over){
				graphics.setColor(Color.red);
				graphics.drawString(GameDictionnary.getInstance().get("lost"), 300, 300);
			}
			String str = GameDictionnary.getInstance().get("score")+score;
			graphics.setColor(Color.black);
			graphics.drawString(str, 100, 100);
		}
		
	}

	@Override
	public void update(GameContainer container, StateBasedGame state, int delta) throws SlickException {
		if(!this.over && !this.pause){
			this.score += System.currentTimeMillis() - timestamp;
			for(Bird b : birds){
				b.auto();
			}
		} else {
			
		}
		timestamp = System.currentTimeMillis();
	}

	@Override
	public int getID() {
		return id;
	}
	
	@Override
	public void keyPressed(int key, char c) {
		int x = 0;
		int y = 0;
		switch (c) {
			case 'z':
				y--;
				break;
			case 'w':
				y--;
				break;
			case 'q':
				x--;
				break;
			case 'a':
				x--;
				break;
			case 's':
				y++;
				break;
			case 'd':
				x++;
			case 'r':
				break;
			case 'p':
				this.pause = !this.pause;
				break;
			case '+':
				spawnBird();
				break;
			default:
				break;
		}
		if(!this.over && !this.pause){
			fish.move(x, y);
		}
	}
	
	public void finish(){
		this.over = true;
	}
	public void unspawn(Bird b){
		//this.birds.remove(b);
	}


}
